setWithPriority method
JSPromise<JSAny?>
setWithPriority(
- JSAny? value,
- JSAny? priority, [
- JSFunction<
Function> onComplete
Ensures the data at this location is set to the specified value and priority when the client is disconnected (due to closing the browser, navigating to a new page, or network issues).
Implementation
external JSPromise<JSAny?> setWithPriority(
JSAny? value,
JSAny? priority, [
// (a: Error | null) => any
JSFunction onComplete,
]);